@@ -121,7 +121,7 @@ class ParaDateFiledServer(object):
 
     def getUtcEndTime(self):
         info = {
-            'year': time.strftime("%Y", time.localtime()),
+            'year': str(int(time.strftime("%Y", time.localtime())) + 1),
             'month': time.strftime("%m", time.localtime()),
             'day': time.strftime("%d", time.localtime()),
             'hour': time.strftime("%H", time.localtime()),
