@@ -1,4 +1,4 @@
-from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port
+from aishu.datafaker.profession.entity import name, switch, ip, timestamp, ml, kai, objectManager, index, agent ,id ,port,logwarehouse
 from aishu.datafaker.profession.entity.ParaDateFiled import ParaDateFiledServer
 from aishu.datafaker.profession.entity.RetrievesAssociated import ParaDateAnyRobotServer
 
@@ -67,7 +67,18 @@ def filed(key,inquire=[]):
         'DeleteAlertRuleNamesID': ParaDateAnyRobotServer(key).getDeleteAlertRuleNamesId,
         'UpdateTimeID': ParaDateFiledServer().getUpdateTime,
         'UtcStartID': ParaDateFiledServer().getUtcStartTime,
-        'UtcEndID': ParaDateFiledServer().getUtcEndTime
+        'UtcEndID': ParaDateFiledServer().getUtcEndTime,
+        'LogwareHouse': ParaDateAnyRobotServer(key).getLogwareHouse,
+        'dataType': ParaDateAnyRobotServer(key).getdataType,
+        'indexID': ParaDateAnyRobotServer(key).getindexID,
+        'indexName': ParaDateAnyRobotServer(key).getindexName,
+        'StreamId': ParaDateAnyRobotServer(key).getStreamId,
+        'LogGroupIdPare': ParaDateAnyRobotServer(key).getLogGroupIdPare,
+        'UserID': ParaDateAnyRobotServer(key).getUserID,
+        'RoleId': ParaDateAnyRobotServer(key).getRoleId,
+        'tagGroupID': ParaDateAnyRobotServer(key).gettagGroupID,
+        'tagID': ParaDateAnyRobotServer(key).gettagID,
+        'HostID': ParaDateAnyRobotServer(key).getIp
     }
 
     switcher = SERVICE_KPI_
